Read-only mirrors. Development, issues and pull requests are on GitHub.

summaryrefslogtreecommitdiffhomepage
path: root/include/internal/catch_stringref.cpp
diff options
context:
space:
mode:
authorNeal Coombes2017-06-21 13:34:58 -0500
committerMartin Hořeňovský2017-06-22 18:03:47 +0200
commitdcab8a59716d785ad2ed8512a35f27b671ae1b20 (patch)
treebff4038e64fe98fbcfb4c2fadced42e90b324665 /include/internal/catch_stringref.cpp
parent017a63da62ba7ffce1e1b005e6adc846412c575b (diff)
downloadcatch3-dcab8a59716d785ad2ed8512a35f27b671ae1b20.tar.gz
Performance improvement in AssertionInfo.
By using char const * instead of std::string we avoid significant copying per assertion. In a simple loop with 10000000 CHECKS on my system, this reduces the run time from 9.8s to 6s.
Diffstat (limited to 'include/internal/catch_stringref.cpp')
0 files changed, 0 insertions, 0 deletions